AGENT SKILLS · EQUIPAMENTO DE MISSÃO / mohitmishra786

mohitmishra786 · Agent Skills

102 skills with substantive source documentation and an official publisher or observed installation demand. Read each skill’s original documentation through its card.

mohitmishra786
Comunidade

mlir

MLIR skill for multi-level intermediate representation. Use when writing custom dialects, defining ops with ODS, writing lowering passes, running mlir-opt, or building ML compilers with Torch-MLIR/IREE. Activates on queries about MLIR, dialect, ODS, mlir-opt, linalg, lowering pass, or Torch-MLIR.

instalações
1
GitHub Stars
263
Atualizado
27 de jun.
mohitmishra786
Comunidade

mpi

MPI skill for distributed-memory parallel programming. Use when writing MPISend/Recv programs, collective operations, non-blocking communication, MPI+OpenMP hybrid, or debugging with mpirun. Activates on queries about MPIInit, MPIAllreduce, MPIIsend, mpirun, MPI-IO, or MPI performance.

instalações
1
GitHub Stars
267
Atualizado
27 de jun.
mohitmishra786
Comunidade

msvc-cl

MSVC cl.exe and clang-cl skill for Windows C/C++ projects. Use when configuring Visual Studio builds, MSBuild, or clang-cl as a drop-in MSVC replacement. Covers translating GCC/Clang flags to MSVC equivalents, runtime library selection, Windows SDK setup, and diagnosing MSVC-specific errors. Activates on queries about cl.exe, clang-cl, /O flags, /MT vs /MD, PDB files, Windows ABI, or MSVC project settings.

instalações
1
GitHub Stars
263
Atualizado
27 de jun.
mohitmishra786
Comunidade

numa-programming

NUMA programming skill for multi-socket memory locality. Use when detecting NUMA topology, binding processes with numactl, using libnuma API, building NUMA-aware data structures, or measuring remote access penalties. Activates on queries about numactl, libnuma, NUMA topology, mbind, lstopo, or remote memory access.

instalações
1
GitHub Stars
263
Atualizado
27 de jun.
mohitmishra786
Comunidade

openocd-jtag

OpenOCD skill for embedded hardware debugging. Use when configuring OpenOCD for JTAG or SWD targets, flashing firmware, connecting GDB to bare-metal targets, setting hardware watchpoints, or using J-Link with OpenOCD. Activates on queries about OpenOCD, JTAG, SWD, GDB remote target, flash programming, hardware breakpoints, J-Link, or connecting GDB to an MCU.

instalações
1
GitHub Stars
267
Atualizado
27 de jun.
mohitmishra786
Comunidade

os-dev-scratch

OS development from scratch skill for bootloader through context switching. Use when building a minimal x86-64 OS, setting up GDT/IDT/page tables, writing keyboard/serial drivers, or using QEMU for kernel boot. Activates on queries about bootloader, long mode, page tables, IDT, PIC/APIC, xv6, or x8664-elf-gcc.

instalações
1
GitHub Stars
267
Atualizado
27 de jun.
mohitmishra786
Comunidade

pgo

Profile-guided optimisation skill for C/C++ with GCC and Clang. Use when squeezing maximum runtime performance after standard optimisation plateaus, implementing two-stage PGO builds, collecting profile data, or applying BOLT for post-link optimisation. Activates on queries about PGO, profile-guided optimization, fprofile-generate, fprofile-use, instrumented builds, or BOLT.

instalações
1
GitHub Stars
267
Atualizado
27 de jun.
mohitmishra786
Comunidade

platform-device-model

Platform device model skill for Linux driver binding. Use when implementing platformdriver probe/remove, sysfs attributes, device properties, or deferred probe. Activates on queries about platformdevice, platformdriver, driver model, sysfs, probe remove, or Linux device bus.

instalações
1
GitHub Stars
263
Atualizado
27 de jun.
mohitmishra786
Comunidade

protocol-analysis

Protocol analysis skill for serial bus debugging. Use when decoding I2C/SPI/UART with logic analyzer concepts, sigrok/PulseView, or Python capture scripts. Activates on queries about logic analyzer, sigrok, PulseView, decode I2C SPI UART, or bus protocol capture.

instalações
1
GitHub Stars
263
Atualizado
27 de jun.
mohitmishra786
Comunidade

qemu-for-kernel-development

QEMU kernel development skill for driver and kernel testing. Use when booting custom kernels in QEMU, Buildroot/Yocto rootfs, virtio devices, or NFS root for driver iteration. Activates on queries about QEMU kernel dev, Buildroot QEMU, virtio block, kernel module test QEMU, or -append root=

instalações
1
GitHub Stars
263
Atualizado
27 de jun.
mohitmishra786
Comunidade

resource-optimization-lowend

Resource optimization skill for constrained embedded targets. Use when reducing flash/RAM usage, analyzing stack depth, reading linker map files, or tuning size vs speed on MCUs. Activates on queries about firmware size optimization, linker map, stack usage, -Os, flash RAM budget, or bloat analysis.

instalações
1
GitHub Stars
263
Atualizado
27 de jun.
mohitmishra786
Comunidade

riscv-privileged

RISC-V privileged architecture skill for M/S/U modes and traps. Use when handling CSRs, trap handlers, PLIC/CLINT interrupts, OpenSBI integration, page tables Sv39/Sv48, or QEMU virt testing. Activates on queries about RISC-V privileged, mstatus, mtvec, satp, OpenSBI, PLIC, or Sv39.

instalações
1
GitHub Stars
263
Atualizado
27 de jun.
mohitmishra786
Comunidade

rust-async-internals

Rust async internals skill for understanding and debugging async Rust. Use when understanding the Future trait and poll model, Pin and Unpin, tokio task scheduling, debugging async stack traces with tokio-console, tracking waker leaks, using select! and join!, or avoiding blocking in async contexts. Activates on queries about Rust async internals, Future poll, Pin, Unpin, tokio-console, waker, async stack traces, select!, join!, or blocking in async.

instalações
1
GitHub Stars
263
Atualizado
27 de jun.
mohitmishra786
Comunidade

rust-cross

Rust cross-compilation skill. Use when building Rust binaries for a different target architecture or OS, using cross or cargo-zigbuild for hermetic cross-compilation, configuring .cargo/config.toml for cross targets, or targeting embedded and bare-metal systems. Activates on queries about Rust cross-compilation, rustup targets, cross tool, cargo-zigbuild, aarch64-unknown-linux-gnu, thumbv7m-none-eabi, or building for embedded.

instalações
1
GitHub Stars
263
Atualizado
27 de jun.
mohitmishra786
Comunidade

rust-debugging

Rust debugging skill for systems programming. Use when debugging Rust binaries with GDB or LLDB, enabling Rust pretty-printers, interpreting panics and backtraces, debugging async/await with tokio-console, stepping through nostd code, or using dbg! and tracing macros effectively. Activates on queries about rust-gdb, rust-lldb, RUSTBACKTRACE, Rust panics, debugging async Rust, tokio-console, or pretty-printers.

instalações
1
GitHub Stars
263
Atualizado
27 de jun.
mohitmishra786
Comunidade

rust-ffi

Rust FFI skill for C interoperability. Use when calling C libraries from Rust, generating Rust bindings with bindgen, exporting Rust functions to C with cbindgen, writing safe wrappers around unsafe FFI, or linking system and vendor libraries. Activates on queries about bindgen, cbindgen, extern "C", unsafe FFI, Rust C bindings, linking C from Rust, or sys crates.

instalações
1
GitHub Stars
223
Atualizado
27 de jun.
mohitmishra786
Comunidade

rust-profiling

Rust profiling skill for performance analysis. Use when generating flamegraphs from Rust binaries, measuring monomorphization bloat with cargo-llvm-lines, analysing binary size with cargo-bloat, microbenchmarking with Criterion, or interpreting inlined frames in profiles. Activates on queries about cargo flamegraph, cargo-bloat, cargo-llvm-lines, Criterion benchmarks, Rust performance profiling, or binary size analysis.

instalações
1
GitHub Stars
263
Atualizado
27 de jun.
mohitmishra786
Comunidade

rust-sanitizers-miri

Rust sanitizers and Miri skill for memory safety validation. Use when running AddressSanitizer or ThreadSanitizer on Rust code, interpreting sanitizer reports, using Miri to detect undefined behaviour in unsafe Rust, or validating unsafe code correctness. Activates on queries about Rust ASan, Rust TSan, Miri, RUSTFLAGS sanitize, cargo miri, unsafe Rust UB, or interpreting Rust sanitizer output.

instalações
1
GitHub Stars
263
Atualizado
27 de jun.
mohitmishra786
Comunidade

rust-unsafe

Rust unsafe code skill for systems programming. Use when writing or reviewing unsafe Rust, understanding what operations require unsafe, implementing safe abstractions over unsafe code, auditing unsafe blocks, or understanding raw pointers, transmute, and extern. Activates on queries about unsafe Rust, raw pointers, transmute, unsafe blocks, writing safe wrappers, UnsafeCell, unsafe trait impl, or auditing unsafe code.

instalações
1
GitHub Stars
223
Atualizado
27 de jun.
mohitmishra786
Comunidade

spi-i2c-baremetal

Bare-metal SPI and I2C skill for serial peripheral buses. Use when implementing master-mode transfers, register read/write protocols, or debugging bus stalls. Activates on queries about SPI bare-metal, I2C START/STOP, sensor register read, or clock phase/polarity.

instalações
1
GitHub Stars
263
Atualizado
27 de jun.
mohitmishra786
Comunidade

stm32-baremetal

STM32 bare-metal skill for CMSIS-only MCU projects. Use when scaffolding STM32 firmware without HAL, configuring clocks/RCC, using CMSIS headers, or building with arm-none-eabi-gcc. Activates on queries about STM32 bare metal, CMSIS without HAL, STM32F4/H7 bring-up, or minimal Makefile CMake for Cortex-M.

instalações
1
GitHub Stars
263
Atualizado
27 de jun.
mohitmishra786
Comunidade

timers-pwm-baremetal

Bare-metal timer and PWM skill. Use when configuring general-purpose timers for PWM, input capture, or periodic ticks without RTOS. Activates on queries about timer prescaler, PWM duty cycle, input capture, or SysTick bare-metal.

instalações
1
GitHub Stars
263
Atualizado
27 de jun.
mohitmishra786
Comunidade

triton-lang

Triton language skill for Python GPU kernel authoring. Use when writing Triton kernels with @triton.jit, tl.load/store, masking, atomics, benchmarking with triton.testing, or integrating kernels into PyTorch. Activates on queries about Triton, tl.constexpr, block pointers, Triton benchmarking, or PyTorch custom ops.

instalações
1
GitHub Stars
263
Atualizado
27 de jun.
mohitmishra786
Comunidade

uart-serial-baremetal

Bare-metal UART skill for serial console and debug. Use when configuring baud rate, polling or IRQ-driven TX/RX, or integrating DMA with UART. Activates on queries about UART bare-metal, baud BRR, serial printf, or USART interrupt.

instalações
1
GitHub Stars
263
Atualizado
27 de jun.